==> neo4j-lucene-index-2.1.5-sources.jar: org/neo4j/kernel/api/impl/index/DirectorySupport.java <==
/**
 * Copyright (c) 2002-2014 "Neo Technology,"
 * Network Engine for Objects in Lund AB [http://neotechnology.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.neo4j.kernel.api.impl.index;

import java.io.IOException;

import org.apache.lucene.store.Directory;

import org.neo4j.kernel.impl.util.FileUtils.FileOperation;

import static org.neo4j.kernel.impl.util.FileUtils.windowsSafeIOOperation;

public class DirectorySupport
{
    public static void deleteDirectoryContents( final Directory directory ) throws IOException
    {
        for ( final String fileName : directory.listAll() )
        {
            windowsSafeIOOperation( new FileOperation()
            {
                @Override
                public void perform() throws IOException
                {
                    directory.deleteFile( fileName );
                }
            } );
        }
    }
}

==> neo4j-lucene-index-2.2.4-sources.jar: org/neo4j/kernel/api/impl/index/DirectorySupport.java <==
/*
 * Copyright (c) 2002-2015 "Neo Technology,"
 * Network Engine for Objects in Lund AB [http://neotechnology.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.neo4j.kernel.api.impl.index;

import java.io.IOException;

import org.apache.lucene.store.Directory;

import org.neo4j.io.fs.FileUtils.FileOperation;

import static org.neo4j.io.fs.FileUtils.windowsSafeIOOperation;

public class DirectorySupport
{
    public static void deleteDirectoryContents( final Directory directory ) throws IOException
    {
        for ( final String fileName : directory.listAll() )
        {
            windowsSafeIOOperation( new FileOperation()
            {
                @Override
                public void perform() throws IOException
                {
                    directory.deleteFile( fileName );
                }
            } );
        }
    }
}
